//Conventions:
//    Global constants (declared with const) and #defines - all uppercase letters with words separated 
//        by underscores.
//        (E.G., #define MY_DEFINE 5).
//        (E.G., const int MY_CONSTANT = 5;).
//    New data types (classes, structs, typedefs, etc.) - begin with an uppercase letter followed by
//        lowercase words separated by uppercase letters.  Enumerated constants contain a prefix
//        associating them with a particular enumerated set.
//        (E.G., typedef int MyTypedef;).
//        (E.G., enum MyEnumConst {MEC_ONE, MEC_TWO};)
//    Global variables - begin with "g_" followed by lowercase words separated by underscores.
//        (E.G., int g_my_global;).
//    Local variables - begin with a lowercase letter followed by lowercase words separated by
//        underscores.
//        (E.G., int my_local;).
//    Argument variables - begin with "a_" followed by lowercase words separated by underscores.
//        (E.G., ...int a_my_argument, ...).
//    Member variables - begin with "m_" followed by lowercase words separated by underscores.
//        (E.G., int m_my_member;).
//    Functions (member or global) - begin with an uppercase letter followed by lowercase words
//        separated by uppercase letters.
//        (E.G., void MyFunction(void);).


//******************************************************************************************************
//**** PROJECT HEADER FILES
//******************************************************************************************************
#include "DocumentApp.h"
#include "FileDocumentWindow.h"
#include "WindowPositionSet.h"


//******************************************************************************************************
//**** CLASS DECLARATIONS
//******************************************************************************************************
class ImageDumpApp : public DocumentApp
{
	public:
		ImageDumpApp();
		virtual ~ImageDumpApp();
		virtual void MessageReceived(BMessage* a_message);
		virtual void RefsReceived(BMessage *a_message);
		virtual void ArgvReceived(int32 argc, char **argv);
		virtual void ReadyToRun();

	private:
		void OpenNewDocument();
		int32 m_doc_title_number;
		WindowPositionSet m_window_position_set;
		BFilePanel* m_open_panel;
};


class ImageView;
class BitmapImageWindow : public FileDocumentWindow
{
	public:
		BitmapImageWindow(BRect a_frame,const char* a_filename);
		virtual ~BitmapImageWindow();
		virtual void MessageReceived(BMessage* a_message);
		virtual bool Save();

	private:
		BMenuBar* GenerateMenuBar();
		ImageView* m_image_view;
		BMenuItem* item_CMAP8;
		BMenuItem* item_RGB32;
};


class ImageView : public BView
{
	public:
		ImageView(BRect a_frame);
		virtual ~ImageView();
		virtual void Draw(BRect a_update_rect);
		void SetBitmap(BBitmap* a_bitmap);
		const BBitmap* GetBitmap();

	private:
		BBitmap* m_bitmap;
};

//******************************************************************************************************
//**** CONSTANTS
//******************************************************************************************************
const int32 MSG_NEW_DOCUMENT = 'NewD';	//LOL
const int32 MSG_OPEN_DOCUMENT = 'Open';
const int32 MSG_CMAP8 = 'CoM8';
const int32 MSG_RGB32 = 'Co32';
